@@ -12,6 +12,7 @@ from .internal.openapi_client.api.application import (
     update_application_api_v1_app_app_id_put,
 )
 from .internal.openapi_client.api.authentication import (
+    get_app_portal_access_api_v1_auth_app_portal_access_app_id_post,
     get_dashboard_access_api_v1_auth_dashboard_access_app_id_post,
     logout_api_v1_auth_logout_post,
 )
@@ -22,10 +23,13 @@ from .internal.openapi_client.api.endpoint import (
     get_endpoint_headers_api_v1_app_app_id_endpoint_endpoint_id_headers_get,
     get_endpoint_secret_api_v1_app_app_id_endpoint_endpoint_id_secret_get,
     get_endpoint_stats_api_v1_app_app_id_endpoint_endpoint_id_stats_get,
+    get_endpoint_transformation_api_v1_app_app_id_endpoint_endpoint_id_transformation_get,
     list_endpoints_api_v1_app_app_id_endpoint_get,
     patch_endpoint_headers_api_v1_app_app_id_endpoint_endpoint_id_headers_patch,
     recover_failed_webhooks_api_v1_app_app_id_endpoint_endpoint_id_recover_post,
+    replay_missing_webhooks_api_v1_app_app_id_endpoint_endpoint_id_replay_missing_post,
     rotate_endpoint_secret_api_v1_app_app_id_endpoint_endpoint_id_secret_rotate_post,
+    set_endpoint_transformation_api_v1_app_app_id_endpoint_endpoint_id_transformation_patch,
     update_endpoint_api_v1_app_app_id_endpoint_endpoint_id_put,
     update_endpoint_headers_api_v1_app_app_id_endpoint_endpoint_id_headers_put,
 )
@@ -47,10 +51,12 @@ from .internal.openapi_client.api.integration import (
 )
 from .internal.openapi_client.api.message import (
     create_message_api_v1_app_app_id_msg_post,
+    expunge_message_payload_api_v1_app_app_id_msg_msg_id_content_delete,
     get_message_api_v1_app_app_id_msg_msg_id_get,
     list_messages_api_v1_app_app_id_msg_get,
 )
 from .internal.openapi_client.api.message_attempt import (
+    expunge_attempt_content_api_v1_app_app_id_msg_msg_id_attempt_attempt_id_content_delete,
     get_attempt_api_v1_app_app_id_msg_msg_id_attempt_attempt_id_get,
     list_attempted_destinations_api_v1_app_app_id_msg_msg_id_endpoint_get,
     list_attempted_messages_api_v1_app_app_id_endpoint_endpoint_id_msg_get,
@@ -60,6 +66,8 @@ from .internal.openapi_client.api.message_attempt import (
     resend_webhook_api_v1_app_app_id_msg_msg_id_endpoint_endpoint_id_resend_post,
 )
 from .internal.openapi_client.client import AuthenticatedClient
+from .internal.openapi_client.models.app_portal_access_in import AppPortalAccessIn
+from .internal.openapi_client.models.app_portal_access_out import AppPortalAccessOut
 from .internal.openapi_client.models.application_in import ApplicationIn
 from .internal.openapi_client.models.application_out import ApplicationOut
 from .internal.openapi_client.models.dashboard_access_out import DashboardAccessOut
@@ -72,6 +80,8 @@ from .internal.openapi_client.models.endpoint_out import EndpointOut
 from .internal.openapi_client.models.endpoint_secret_out import EndpointSecretOut
 from .internal.openapi_client.models.endpoint_secret_rotate_in import EndpointSecretRotateIn
 from .internal.openapi_client.models.endpoint_stats import EndpointStats
+from .internal.openapi_client.models.endpoint_transformation_in import EndpointTransformationIn
+from .internal.openapi_client.models.endpoint_transformation_out import EndpointTransformationOut
 from .internal.openapi_client.models.endpoint_update import EndpointUpdate
 from .internal.openapi_client.models.event_type_in import EventTypeIn
 from .internal.openapi_client.models.event_type_out import EventTypeOut
@@ -99,6 +109,8 @@ from .internal.openapi_client.models.message_out_payload import MessageOutPayloa
 from .internal.openapi_client.models.message_status import MessageStatus
 from .internal.openapi_client.models.recover_in import RecoverIn
 from .internal.openapi_client.models.recover_out import RecoverOut
+from .internal.openapi_client.models.replay_in import ReplayIn
+from .internal.openapi_client.models.replay_out import ReplayOut
 from .internal.openapi_client.models.status_code_class import StatusCodeClass
 
 DEFAULT_SERVER_URL = "https://api.svix.com"
@@ -174,6 +186,13 @@ class ApiBase:
 
 
 class AuthenticationAsync(ApiBase):
+    async def app_portal_access(
+        self, app_id: str, app_portal_access_in: AppPortalAccessIn, options: PostOptions = PostOptions()
+    ) -> AppPortalAccessOut:
+        return await get_app_portal_access_api_v1_auth_app_portal_access_app_id_post.asyncio(
+            client=self._client, app_id=app_id, json_body=app_portal_access_in, **options.to_dict()
+        )
+
     async def dashboard_access(self, app_id: str, options: PostOptions = PostOptions()) -> DashboardAccessOut:
         return await get_dashboard_access_api_v1_auth_dashboard_access_app_id_post.asyncio(
             client=self._client, app_id=app_id, **options.to_dict()
@@ -184,6 +203,13 @@ class AuthenticationAsync(ApiBase):
 
 
 class Authentication(ApiBase):
+    def app_portal_access(
+        self, app_id: str, app_portal_access_in: AppPortalAccessIn, options: PostOptions = PostOptions()
+    ) -> AppPortalAccessOut:
+        return get_app_portal_access_api_v1_auth_app_portal_access_app_id_post.sync(
+            client=self._client, app_id=app_id, json_body=app_portal_access_in, **options.to_dict()
+        )
+
     def dashboard_access(self, app_id: str, options: PostOptions = PostOptions()) -> DashboardAccessOut:
         return get_dashboard_access_api_v1_auth_dashboard_access_app_id_post.sync(
             client=self._client, app_id=app_id, **options.to_dict()
@@ -339,6 +365,28 @@ class EndpointAsync(ApiBase):
             json_body=endpoint_headers_in,
         )
 
+    async def replay_missing(
+        self, app_id: str, endpoint_id: str, replay_in: ReplayIn, options: PostOptions = PostOptions()
+    ) -> ReplayOut:
+        return await replay_missing_webhooks_api_v1_app_app_id_endpoint_endpoint_id_replay_missing_post.asyncio(
+            client=self._client, app_id=app_id, endpoint_id=endpoint_id, json_body=replay_in, **options.to_dict()
+        )
+
+    async def transformations_get(self, app_id: str, endpoint_id: str) -> EndpointTransformationOut:
+        return await get_endpoint_transformation_api_v1_app_app_id_endpoint_endpoint_id_transformation_get.asyncio(
+            client=self._client, app_id=app_id, endpoint_id=endpoint_id
+        )
+
+    async def transformation_partial_update(
+        self, app_id: str, endpoint_id: str, endpoint_transformation_in: EndpointTransformationIn
+    ) -> None:
+        await set_endpoint_transformation_api_v1_app_app_id_endpoint_endpoint_id_transformation_patch.asyncio(
+            client=self._client,
+            app_id=app_id,
+            endpoint_id=endpoint_id,
+            json_body=endpoint_transformation_in,
+        )
+
 
 class Endpoint(ApiBase):
     def list(self, app_id: str, options: EndpointListOptions = EndpointListOptions()) -> ListResponseEndpointOut:
@@ -439,6 +487,28 @@ class Endpoint(ApiBase):
             endpoint_id=endpoint_id,
         )
 
+    def replay_missing(
+        self, app_id: str, endpoint_id: str, replay_in: ReplayIn, options: PostOptions = PostOptions()
+    ) -> ReplayOut:
+        return replay_missing_webhooks_api_v1_app_app_id_endpoint_endpoint_id_replay_missing_post.sync(
+            client=self._client, app_id=app_id, endpoint_id=endpoint_id, json_body=replay_in, **options.to_dict()
+        )
+
+    def transformations_get(self, app_id: str, endpoint_id: str) -> EndpointTransformationOut:
+        return get_endpoint_transformation_api_v1_app_app_id_endpoint_endpoint_id_transformation_get.sync(
+            client=self._client, app_id=app_id, endpoint_id=endpoint_id
+        )
+
+    def transformation_partial_update(
+        self, app_id: str, endpoint_id: str, endpoint_transformation_in: EndpointTransformationIn
+    ) -> None:
+        set_endpoint_transformation_api_v1_app_app_id_endpoint_endpoint_id_transformation_patch.sync(
+            client=self._client,
+            app_id=app_id,
+            endpoint_id=endpoint_id,
+            json_body=endpoint_transformation_in,
+        )
+
 
 class EventTypeAsync(ApiBase):
     async def list(self, options: EventTypeListOptions = EventTypeListOptions()) -> ListResponseEventTypeOut:
@@ -648,6 +718,13 @@ class MessageAsync(ApiBase):
             msg_id=msg_id,
         )
 
+    async def expunge_content(self, app_id: str, msg_id: str) -> None:
+        return await expunge_message_payload_api_v1_app_app_id_msg_msg_id_content_delete.asyncio(
+            client=self._client,
+            app_id=app_id,
+            msg_id=msg_id,
+        )
+
 
 class Message(ApiBase):
     def list(self, app_id: str, options: MessageListOptions = MessageListOptions()) -> ListResponseMessageOut:
@@ -675,6 +752,13 @@ class Message(ApiBase):
             msg_id=msg_id,
         )
 
+    def expunge_content(self, app_id: str, msg_id: str) -> None:
+        return expunge_message_payload_api_v1_app_app_id_msg_msg_id_content_delete.sync(
+            client=self._client,
+            app_id=app_id,
+            msg_id=msg_id,
+        )
+
 
 class MessageAttemptAsync(ApiBase):
     async def list_by_msg(
@@ -743,6 +827,19 @@ class MessageAttemptAsync(ApiBase):
             **options.to_dict(),
         )
 
+    async def expunge_content(
+        self,
+        app_id: str,
+        msg_id: str,
+        attempt_id: str,
+    ) -> None:
+        return await expunge_attempt_content_api_v1_app_app_id_msg_msg_id_attempt_attempt_id_content_delete.asyncio(
+            client=self._client,
+            app_id=app_id,
+            msg_id=msg_id,
+            attempt_id=attempt_id,
+        )
+
 
 class MessageAttempt(ApiBase):
     @deprecated(reason="use list_by_msg or list_by_endpoint instead")
@@ -817,6 +914,19 @@ class MessageAttempt(ApiBase):
             **options.to_dict(),
         )
 
+    def expunge_content(
+        self,
+        app_id: str,
+        msg_id: str,
+        attempt_id: str,
+    ) -> None:
+        return expunge_attempt_content_api_v1_app_app_id_msg_msg_id_attempt_attempt_id_content_delete.sync(
+            client=self._client,
+            app_id=app_id,
+            msg_id=msg_id,
+            attempt_id=attempt_id,
+        )
+
 
 class ClientBase:
     _client: AuthenticatedClient
