@@ -16,14 +16,14 @@ def _get_kwargs(
     client: AuthenticatedClient,
     iterator: Union[Unset, None, str] = UNSET,
     limit: Union[Unset, None, int] = 50,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/app/".format(client.base_url)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     params: Dict[str, Any] = {}
@@ -70,7 +70,7 @@ def sync_detailed(
     client: AuthenticatedClient,
     iterator: Union[Unset, None, str] = UNSET,
     limit: Union[Unset, None, int] = 50,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseApplicationOut:
     """List Applications
 
@@ -79,7 +79,7 @@ def sync_detailed(
     Args:
         iterator (Union[Unset, None, str]):  Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         limit (Union[Unset, None, int]):  Default: 50.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseApplicationOut
@@ -116,7 +116,7 @@ def sync(
     client: AuthenticatedClient,
     iterator: Union[Unset, None, str] = UNSET,
     limit: Union[Unset, None, int] = 50,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseApplicationOut:
     """List Applications
 
@@ -125,7 +125,7 @@ def sync(
     Args:
         iterator (Union[Unset, None, str]):  Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         limit (Union[Unset, None, int]):  Default: 50.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseApplicationOut
@@ -144,7 +144,7 @@ async def asyncio_detailed(
     client: AuthenticatedClient,
     iterator: Union[Unset, None, str] = UNSET,
     limit: Union[Unset, None, int] = 50,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseApplicationOut:
     """List Applications
 
@@ -153,7 +153,7 @@ async def asyncio_detailed(
     Args:
         iterator (Union[Unset, None, str]):  Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         limit (Union[Unset, None, int]):  Default: 50.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseApplicationOut
@@ -188,7 +188,7 @@ async def asyncio(
     client: AuthenticatedClient,
     iterator: Union[Unset, None, str] = UNSET,
     limit: Union[Unset, None, int] = 50,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseApplicationOut:
     """List Applications
 
@@ -197,7 +197,7 @@ async def asyncio(
     Args:
         iterator (Union[Unset, None, str]):  Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         limit (Union[Unset, None, int]):  Default: 50.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseApplicationOut
