@@ -62,9 +62,11 @@ def sync_detailed(
     client: AuthenticatedClient,
     idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> DashboardAccessOut:
-    """Get Consumer App Portal Access
+    """Get Dashboard Access
 
-     Use this function to get magic links (and authentication codes) for connecting your users to the
+     DEPRECATED: Please use `app-portal-access` instead.
+
+    Use this function to get magic links (and authentication codes) for connecting your users to the
     Consumer Application Portal.
 
     Args:
@@ -106,9 +108,11 @@ def sync(
     client: AuthenticatedClient,
     idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> DashboardAccessOut:
-    """Get Consumer App Portal Access
+    """Get Dashboard Access
 
-     Use this function to get magic links (and authentication codes) for connecting your users to the
+     DEPRECATED: Please use `app-portal-access` instead.
+
+    Use this function to get magic links (and authentication codes) for connecting your users to the
     Consumer Application Portal.
 
     Args:
@@ -132,9 +136,11 @@ async def asyncio_detailed(
     client: AuthenticatedClient,
     idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> DashboardAccessOut:
-    """Get Consumer App Portal Access
+    """Get Dashboard Access
 
-     Use this function to get magic links (and authentication codes) for connecting your users to the
+     DEPRECATED: Please use `app-portal-access` instead.
+
+    Use this function to get magic links (and authentication codes) for connecting your users to the
     Consumer Application Portal.
 
     Args:
@@ -174,9 +180,11 @@ async def asyncio(
     client: AuthenticatedClient,
     idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> DashboardAccessOut:
-    """Get Consumer App Portal Access
+    """Get Dashboard Access
 
-     Use this function to get magic links (and authentication codes) for connecting your users to the
+     DEPRECATED: Please use `app-portal-access` instead.
+
+    Use this function to get magic links (and authentication codes) for connecting your users to the
     Consumer Application Portal.
 
     Args:
