@@ -13,14 +13,14 @@ from ...types import UNSET, Unset
 def _get_kwargs(
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/auth/logout/".format(client.base_url)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     return {
@@ -56,7 +56,7 @@ num_retries = 3
 def sync_detailed(
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> None:
     """Logout
 
@@ -65,7 +65,7 @@ def sync_detailed(
     Trying to log out other tokens will fail.
 
     Args:
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         None
@@ -98,7 +98,7 @@ def sync_detailed(
 def sync(
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> None:
     """Logout
 
@@ -107,7 +107,7 @@ def sync(
     Trying to log out other tokens will fail.
 
     Args:
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         None
@@ -122,7 +122,7 @@ def sync(
 async def asyncio_detailed(
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> None:
     """Logout
 
@@ -131,7 +131,7 @@ async def asyncio_detailed(
     Trying to log out other tokens will fail.
 
     Args:
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         None
@@ -162,7 +162,7 @@ async def asyncio_detailed(
 async def asyncio(
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> None:
     """Logout
 
@@ -171,7 +171,7 @@ async def asyncio(
     Trying to log out other tokens will fail.
 
     Args:
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         None
