@@ -14,14 +14,14 @@ def _get_kwargs(
     event_type_name: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/event-type/{event_type_name}/".format(client.base_url, event_type_name=event_type_name)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     return {
@@ -58,7 +58,7 @@ def sync_detailed(
     event_type_name: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> None:
     """Archive Event Type
 
@@ -71,7 +71,7 @@ def sync_detailed(
 
     Args:
         event_type_name (str):  Example: user.signup.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         None
@@ -106,7 +106,7 @@ def sync(
     event_type_name: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> None:
     """Archive Event Type
 
@@ -119,7 +119,7 @@ def sync(
 
     Args:
         event_type_name (str):  Example: user.signup.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         None
@@ -136,7 +136,7 @@ async def asyncio_detailed(
     event_type_name: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> None:
     """Archive Event Type
 
@@ -149,7 +149,7 @@ async def asyncio_detailed(
 
     Args:
         event_type_name (str):  Example: user.signup.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         None
@@ -182,7 +182,7 @@ async def asyncio(
     event_type_name: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> None:
     """Archive Event Type
 
@@ -195,7 +195,7 @@ async def asyncio(
 
     Args:
         event_type_name (str):  Example: user.signup.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         None
