@@ -1,5 +1,7 @@
 """ Contains all the data models used in inputs/outputs """
 
+from .app_portal_access_in import AppPortalAccessIn
+from .app_portal_access_out import AppPortalAccessOut
 from .application_in import ApplicationIn
 from .application_in_metadata import ApplicationInMetadata
 from .application_out import ApplicationOut
