@@ -11,10 +11,10 @@ T = TypeVar("T", bound="FontSizeConfig")
 class FontSizeConfig:
     """
     Attributes:
-        base (Union[Unset, int]):
+        base (Union[Unset, None, int]):
     """
 
-    base: Union[Unset, int] = UNSET
+    base: Union[Unset, None, int] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
