@@ -1,9 +1,11 @@
 import datetime
-from typing import Any, Dict, List, Type, TypeVar
+from typing import Any, Dict, List, Type, TypeVar, Union
 
 import attr
 from dateutil.parser import isoparse
 
+from ..types import UNSET, Unset
+
 T = TypeVar("T", bound="ReplayIn")
 
 
@@ -12,14 +14,20 @@ class ReplayIn:
     """
     Attributes:
         since (datetime.datetime):
+        until (Union[Unset, None, datetime.datetime]):
     """
 
     since: datetime.datetime
+    until: Union[Unset, None, datetime.datetime] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         since = self.since.isoformat()
 
+        until: Union[Unset, None, str] = UNSET
+        if not isinstance(self.until, Unset):
+            until = self.until.isoformat() if self.until else None
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -27,6 +35,8 @@ class ReplayIn:
                 "since": since,
             }
         )
+        if until is not UNSET:
+            field_dict["until"] = until
 
         return field_dict
 
@@ -35,8 +45,18 @@ class ReplayIn:
         dict_copy = src_dict.copy()
         since = isoparse(dict_copy.pop("since"))
 
+        _until = dict_copy.pop("until", UNSET)
+        until: Union[Unset, None, datetime.datetime]
+        if _until is None:
+            until = None
+        elif isinstance(_until, Unset):
+            until = UNSET
+        else:
+            until = isoparse(_until)
+
         replay_in = cls(
             since=since,
+            until=until,
         )
 
         replay_in.additional_properties = dict_copy
